async fn seed_credit_registration_status_templates(
conn: &mut PgConnection,
) -> Result<()>Expand description
The credit registration student mails. Their only link is the status page, since students enrol in different ways.
async fn seed_credit_registration_status_templates(
conn: &mut PgConnection,
) -> Result<()>The credit registration student mails. Their only link is the status page, since students enrol in different ways.